bottom_center

Function bottom_center 

pub fn bottom_center<'a, W, Theme>(content: W) -> Container<'a, W, Theme>
where Theme: Catalog + 'a,
Creates a new Container that fills all the available space and aligns its contents inside to the bottom center.

This is equivalent to:

let bottom_center = container("Bottom Center!").center_x(Fill).align_bottom(Fill);