hover

Function hover 

pub fn hover<W, V>(base: W, top: V) -> Hover<W, V>
Displays a widget on top of another one, only when the base widget is hovered.

This works analogously to a stack, but it will only display the layer on top when the cursor is over the base. It can be useful for removing visual clutter.