lazy

Function lazy 

pub fn lazy<'a, W, Dependency>(
    dependency: Dependency,
    view: impl Fn(&Dependency) -> W + 'a,
) -> Lazy<'a, W, Dependency>
where Dependency: Hash + 'a,
Creates a new Lazy widget with the given data Dependency and a closure that can turn this data into a widget tree.