responsive

Function responsive 

pub fn responsive<'a, W>(f: impl Fn(Size) -> W + 'a) -> Responsive<'a, W>
Creates a new Responsive widget with a closure that produces its contents.

The view closure will receive the maximum available space for the Responsive during layout. You can use this Size to conditionally build the contents.