right_center

Function right_center 

pub fn right_center<'a, W, Theme>(content: W) -> Container<'a, W, Theme>
where Theme: Catalog + 'a,
Creates a new Container that fills all the available space and aligns its contents inside to the right center.

This is equivalent to:

let right_center = container("Bottom Center!").align_right(Fill).center_y(Fill);