pub struct Button<'a, Message, W = Element<'a, Message, Theme, Renderer<Renderer, Renderer>>, Theme = Theme>where
Theme: Catalog,{ /* private fields */ }Expand description
A generic widget that produces a message when pressed.
Example
use iced::widget::button;
#[derive(Clone)]
enum Message {
ButtonPressed,
}
fn view(state: &State) -> impl Widget<Message> {
button("Press me!").on_press(Message::ButtonPressed)
}If a Button::on_press handler is not set, the resulting Button will
be disabled:
use iced::widget::button;
#[derive(Clone)]
enum Message {
ButtonPressed,
}
fn view(state: &State) -> impl Widget<Message> {
button("I am disabled!")
}Implementations
Sourceimpl<'a, Message, W, Theme> Button<'a, Message, W, Theme>where
Theme: Catalog,
impl<'a, Message, W, Theme> Button<'a, Message, W, Theme>where
Theme: Catalog,
Sourcepub fn new(content: W) -> Button<'a, Message, W, Theme>
pub fn new(content: W) -> Button<'a, Message, W, Theme>
Creates a new Button with the given content.
Sourcepub fn width(self, width: impl Into<Length>) -> Button<'a, Message, W, Theme>
pub fn width(self, width: impl Into<Length>) -> Button<'a, Message, W, Theme>
Sets the width of the Button.
Sourcepub fn height(self, height: impl Into<Length>) -> Button<'a, Message, W, Theme>
pub fn height(self, height: impl Into<Length>) -> Button<'a, Message, W, Theme>
Sets the height of the Button.
Sourcepub fn on_press_with(
self,
on_press: impl Fn() -> Message + 'a,
) -> Button<'a, Message, W, Theme>
pub fn on_press_with( self, on_press: impl Fn() -> Message + 'a, ) -> Button<'a, Message, W, Theme>
Sets the message that will be produced when the Button is pressed.
This is analogous to Button::on_press, but using a closure to produce
the message.
This closure will only be called when the Button is actually pressed and,
therefore, this method is useful to reduce overhead if creating the resulting
message is slow.
Sourcepub fn on_press_maybe(
self,
on_press: Option<Message>,
) -> Button<'a, Message, W, Theme>
pub fn on_press_maybe( self, on_press: Option<Message>, ) -> Button<'a, Message, W, Theme>
Sourcepub fn on_press_maybe_with(
self,
on_press: Option<impl Fn() -> Message + 'a>,
) -> Button<'a, Message, W, Theme>
pub fn on_press_maybe_with( self, on_press: Option<impl Fn() -> Message + 'a>, ) -> Button<'a, Message, W, Theme>
Sets the message that will be produced when the Button is pressed,
if Some.
This is analogous to Button::on_press, but using a closure to produce
the message.
This closure will only be called when the Button is actually pressed and,
therefore, this method is useful to reduce overhead if creating the resulting
message is slow.
If None, the Button will be disabled.
Sourcepub fn clip(self, clip: bool) -> Button<'a, Message, W, Theme>
pub fn clip(self, clip: bool) -> Button<'a, Message, W, Theme>
Sets whether the contents of the Button should be clipped on
overflow.