pub struct Stack<W> { /* private fields */ }Expand description
A container that displays children on top of each other.
The first Widget dictates the intrinsic Size of a Stack and
will be displayed as the base layer. Every consecutive Widget will be
rendered on top; on its own layer.
You can use push_under to push a Widget under
the current Stack without affecting its intrinsic Size.
Keep in mind that too much layering will normally produce bad UX as well as introduce certain rendering overhead. Use this widget sparingly!
Implementations
Sourceimpl<W> Stack<W>
impl<W> Stack<W>
Sourcepub fn with_capacity(capacity: usize) -> Stack<W>
pub fn with_capacity(capacity: usize) -> Stack<W>
Creates a Stack with the given capacity.
Sourcepub fn with_children(children: impl IntoIterator<Item = W>) -> Stack<W>where
W: Meta,
pub fn with_children(children: impl IntoIterator<Item = W>) -> Stack<W>where
W: Meta,
Creates a Stack with the given widgets.
Sourcepub fn push(self, child: impl Into<W>) -> Stack<W>where
W: Meta,
pub fn push(self, child: impl Into<W>) -> Stack<W>where
W: Meta,
Adds a widget on top of the Stack.
Sourcepub fn push_under(self, child: impl Into<W>) -> Stack<W>
pub fn push_under(self, child: impl Into<W>) -> Stack<W>
Adds a widget under the Stack.