pub fn bottom_right<'a, W, Theme>(content: W) -> Container<'a, W, Theme>where
Theme: Catalog + 'a,Expand description
Creates a new Container that fills all the available space
and aligns its contents inside to the bottom right corner.
This is equivalent to:
let bottom_right = container("Bottom!").align_right(Fill).align_bottom(Fill);