responsive

Function responsive 

pub fn responsive<'a, Message, Theme, Renderer, E>(
    f: impl Fn(Size) -> E + 'a,
) -> Responsive<'a, Message, Theme, Renderer>
where Renderer: Renderer, E: Into<Element<'a, Message, Theme, Renderer>>,
Creates a new Responsive widget with a closure that produces its contents.

The view closure will receive the maximum available space for the Responsive during layout. You can use this Size to conditionally build the contents.